@@ -70,10 +70,7 @@ void CmdBaseStream::GenReturn (comm_USHORT nRet, rtl::OString *pUId, comm_ULONG
 {
     Write(comm_USHORT(SIReturn));
     Write(nRet);
-    if ( pUId->equals( rtl::OString( "UID_ACTIVE" ) ) )
-        Write(comm_ULONG(0));
-    else
-        Write(pUId);
+    Write(pUId);
     Write(comm_USHORT(PARAM_ULONG_1));			// Typ der folgenden Parameter
     Write(nNr);
 }
@@ -82,10 +79,7 @@ void CmdBaseStream::GenReturn (comm_USHORT nRet, rtl::OString *pUId, comm_String
 {
     Write(comm_USHORT(SIReturn));
     Write(nRet);
-    if ( pUId->equals( rtl::OString( "UID_ACTIVE" ) ) )
-        Write(comm_ULONG(0));
-    else
-        Write(pUId);
+    Write(pUId);
     Write(comm_USHORT(PARAM_STR_1));				// Typ der folgenden Parameter
     Write(pString);
 }
@@ -94,10 +88,7 @@ void CmdBaseStream::GenReturn (comm_USHORT nRet, rtl::OString *pUId, comm_BOOL b
 {
     Write(comm_USHORT(SIReturn));
     Write(nRet);
-    if ( pUId->equals( rtl::OString( "UID_ACTIVE" ) ) )
-        Write(comm_ULONG(0));
-    else
-        Write(pUId);
+    Write(pUId);
     Write(comm_USHORT(PARAM_BOOL_1));			// Typ der folgenden Parameter
     Write(bBool);
 }
@@ -106,10 +97,7 @@ void CmdBaseStream::GenReturn (comm_USHORT nRet, rtl::OString *pUId, comm_ULONG
 {
     Write(comm_USHORT(SIReturn));
     Write(nRet);
-    if ( pUId->equals( rtl::OString( "UID_ACTIVE" ) ) )
-        Write(comm_ULONG(0));
-    else
-        Write(pUId);
+    Write(pUId);
     Write(comm_USHORT(PARAM_ULONG_1|PARAM_STR_1|PARAM_BOOL_1));		// Typ der folgenden Parameter
     Write(nNr);
     Write(pString);
