@@ -1,7 +1,8 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -25,9 +26,6 @@
  *
  ************************************************************************/
 
-// MARKER(update_precomp.py): autogen include statement, do not remove
-#include "precompiled_cui.hxx"
-
 #include <tools/shl.hxx>
 #include <vcl/msgbox.hxx>
 #include <sfx2/viewfrm.hxx>
@@ -40,280 +38,6 @@
 #include <cuires.hrc>
 #include <svx/dialogs.hrc> // RID_SVX_GRFFILTER_DLG_...
 
-// --------------------
-// - SvxGraphicFilter -
-// --------------------
-/*
-ULONG SvxGraphicFilter::ExecuteGrfFilterSlot( SfxRequest& rReq, GraphicObject& rFilterObject )
-{
-    const Graphic&	rGraphic = rFilterObject.GetGraphic();
-    ULONG			nRet;
-
-    if( rGraphic.GetType() == GRAPHIC_BITMAP )
-    {
-        SfxViewFrame*	pViewFrame = SfxViewFrame::Current();
-        SfxObjectShell*	pShell = pViewFrame ? pViewFrame->GetObjectShell() : NULL;
-        Window*			pWindow = ( pViewFrame && pViewFrame->GetViewShell() ) ? pViewFrame->GetViewShell()->GetWindow() : NULL;
-        Graphic			aGraphic;
-
-        switch( rReq.GetSlot() )
-        {
-            case( SID_GRFFILTER_INVERT ):
-            {
-                if( pShell )
-                    pShell->SetWaitCursor( TRUE );
-
-                if( rGraphic.IsAnimated() )
-                {
-                    Animation aAnimation( rGraphic.GetAnimation() );
-
-                    if( aAnimation.Invert() )
-                        aGraphic = aAnimation;
-                }
-                else
-                {
-                    BitmapEx aBmpEx( rGraphic.GetBitmapEx() );
-
-                    if( aBmpEx.Invert() )
-                        aGraphic = aBmpEx;
-                }
-
-                if( pShell )
-                    pShell->SetWaitCursor( FALSE );
-            }
-            break;
-
-            case( SID_GRFFILTER_SMOOTH ):
-            {
-                if( pShell )
-                    pShell->SetWaitCursor( TRUE );
-
-                if( rGraphic.IsAnimated() )
-                {
-                    Animation aAnimation( rGraphic.GetAnimation() );
-
-                    if( aAnimation.Filter( BMP_FILTER_SMOOTH ) )
-                        aGraphic = aAnimation;
-                }
-                else
-                {
-                    BitmapEx aBmpEx( rGraphic.GetBitmapEx() );
-
-                    if( aBmpEx.Filter( BMP_FILTER_SMOOTH ) )
-                        aGraphic = aBmpEx;
-                }
-
-                if( pShell )
-                    pShell->SetWaitCursor( FALSE );
-            }
-            break;
-
-            case( SID_GRFFILTER_SHARPEN ):
-            {
-                if( pShell )
-                    pShell->SetWaitCursor( TRUE );
-
-                if( rGraphic.IsAnimated() )
-                {
-                    Animation aAnimation( rGraphic.GetAnimation() );
-
-                    if( aAnimation.Filter( BMP_FILTER_SHARPEN ) )
-                        aGraphic = aAnimation;
-                }
-                else
-                {
-                    BitmapEx aBmpEx( rGraphic.GetBitmapEx() );
-
-                    if( aBmpEx.Filter( BMP_FILTER_SHARPEN ) )
-                        aGraphic = aBmpEx;
-                }
-
-                if( pShell )
-                    pShell->SetWaitCursor( FALSE );
-            }
-            break;
-
-            case( SID_GRFFILTER_REMOVENOISE ):
-            {
-                if( pShell )
-                    pShell->SetWaitCursor( TRUE );
-
-                if( rGraphic.IsAnimated() )
-                {
-                    Animation aAnimation( rGraphic.GetAnimation() );
-
-                    if( aAnimation.Filter( BMP_FILTER_REMOVENOISE ) )
-                        aGraphic = aAnimation;
-                }
-                else
-                {
-                    BitmapEx aBmpEx( rGraphic.GetBitmapEx() );
-
-                    if( aBmpEx.Filter( BMP_FILTER_REMOVENOISE ) )
-                        aGraphic = aBmpEx;
-                }
-
-                if( pShell )
-                    pShell->SetWaitCursor( FALSE );
-            }
-            break;
-
-            case( SID_GRFFILTER_SOBEL ):
-            {
-                if( pShell )
-                    pShell->SetWaitCursor( TRUE );
-
-                if( rGraphic.IsAnimated() )
-                {
-                    Animation aAnimation( rGraphic.GetAnimation() );
-
-                    if( aAnimation.Filter( BMP_FILTER_SOBEL_GREY ) )
-                        aGraphic = aAnimation;
-                }
-                else
-                {
-                    BitmapEx aBmpEx( rGraphic.GetBitmapEx() );
-
-                    if( aBmpEx.Filter( BMP_FILTER_SOBEL_GREY ) )
-                        aGraphic = aBmpEx;
-                }
-
-                if( pShell )
-                    pShell->SetWaitCursor( FALSE );
-            }
-            break;
-
-            case( SID_GRFFILTER_MOSAIC ):
-            {
-                GraphicFilterMosaic aDlg( pWindow, rGraphic, 4, 4, FALSE );
-
-                if( aDlg.Execute() == RET_OK )
-                    aGraphic = aDlg.GetFilteredGraphic( rGraphic, 1.0, 1.0 );
-            }
-            break;
-
-            case( SID_GRFFILTER_EMBOSS	):
-            {
-                GraphicFilterEmboss aDlg( pWindow, rGraphic, RP_MM );
-
-                if( aDlg.Execute() == RET_OK )
-                    aGraphic = aDlg.GetFilteredGraphic( rGraphic, 1.0, 1.0 );
-            }
-            break;
-
-            case( SID_GRFFILTER_POSTER	):
-            {
-                GraphicFilterPoster aDlg( pWindow, rGraphic, 16 );
-
-                if( aDlg.Execute() == RET_OK )
-                    aGraphic = aDlg.GetFilteredGraphic( rGraphic, 1.0, 1.0 );
-            }
-            break;
-
-            case( SID_GRFFILTER_POPART	):
-            {
-                if( pShell )
-                    pShell->SetWaitCursor( TRUE );
-
-                if( rGraphic.IsAnimated() )
-                {
-                    Animation aAnimation( rGraphic.GetAnimation() );
-
-                    if( aAnimation.Filter( BMP_FILTER_POPART ) )
-                        aGraphic = aAnimation;
-                }
-                else
-                {
-                    BitmapEx aBmpEx( rGraphic.GetBitmapEx() );
-
-                    if( aBmpEx.Filter( BMP_FILTER_POPART ) )
-                        aGraphic = aBmpEx;
-                }
-
-                if( pShell )
-                    pShell->SetWaitCursor( FALSE );
-            }
-            break;
-
-            case( SID_GRFFILTER_SEPIA ):
-            {
-                GraphicFilterSepia aDlg( pWindow, rGraphic, 10 );
-
-                if( aDlg.Execute() == RET_OK )
-                    aGraphic = aDlg.GetFilteredGraphic( rGraphic, 1.0, 1.0 );
-            }
-            break;
-
-            case( SID_GRFFILTER_SOLARIZE ):
-            {
-                GraphicFilterSolarize aDlg( pWindow, rGraphic, 128, FALSE );
-
-                if( aDlg.Execute() == RET_OK )
-                    aGraphic = aDlg.GetFilteredGraphic( rGraphic, 1.0, 1.0 );
-            }
-            break;
-
-            default:
-            {
-                DBG_ERROR( "SvxGraphicFilter: selected filter slot not yet implemented" );
-                nRet = SVX_GRAPHICFILTER_UNSUPPORTED_SLOT;
-            }
-            break;
-        }
-
-        if( aGraphic.GetType() != GRAPHIC_NONE )
-        {
-            rFilterObject.SetGraphic( aGraphic );
-            nRet = SVX_GRAPHICFILTER_ERRCODE_NONE;
-        }
-    }
-    else
-        nRet = SVX_GRAPHICFILTER_UNSUPPORTED_GRAPHICTYPE;
-    
-    return nRet;
-}
-
-// -----------------------------------------------------------------------------
-
-void SvxGraphicFilter::DisableGraphicFilterSlots( SfxItemSet& rSet )
-{
-    if( SFX_ITEM_AVAILABLE <= rSet.GetItemState( SID_GRFFILTER ) )
-        rSet.DisableItem( SID_GRFFILTER );
-
-    if( SFX_ITEM_AVAILABLE <= rSet.GetItemState( SID_GRFFILTER_INVERT ) )
-        rSet.DisableItem( SID_GRFFILTER_INVERT );
-
-    if( SFX_ITEM_AVAILABLE <= rSet.GetItemState( SID_GRFFILTER_SMOOTH ) )
-        rSet.DisableItem( SID_GRFFILTER_SMOOTH );
-
-    if( SFX_ITEM_AVAILABLE <= rSet.GetItemState( SID_GRFFILTER_SHARPEN ) )
-        rSet.DisableItem( SID_GRFFILTER_SHARPEN );
-
-    if( SFX_ITEM_AVAILABLE <= rSet.GetItemState( SID_GRFFILTER_REMOVENOISE ) )
-        rSet.DisableItem( SID_GRFFILTER_REMOVENOISE );
-
-    if( SFX_ITEM_AVAILABLE <= rSet.GetItemState( SID_GRFFILTER_SOBEL ) )
-        rSet.DisableItem( SID_GRFFILTER_SOBEL );
-
-    if( SFX_ITEM_AVAILABLE <= rSet.GetItemState( SID_GRFFILTER_MOSAIC ) )
-        rSet.DisableItem( SID_GRFFILTER_MOSAIC );
-
-    if( SFX_ITEM_AVAILABLE <= rSet.GetItemState( SID_GRFFILTER_EMBOSS ) )
-        rSet.DisableItem( SID_GRFFILTER_EMBOSS );
-
-    if( SFX_ITEM_AVAILABLE <= rSet.GetItemState( SID_GRFFILTER_POSTER ) )
-        rSet.DisableItem( SID_GRFFILTER_POSTER );
-
-    if( SFX_ITEM_AVAILABLE <= rSet.GetItemState( SID_GRFFILTER_POPART ) )
-        rSet.DisableItem( SID_GRFFILTER_POPART );
-
-    if( SFX_ITEM_AVAILABLE <= rSet.GetItemState( SID_GRFFILTER_SEPIA ) )
-        rSet.DisableItem( SID_GRFFILTER_SEPIA );
-
-    if( SFX_ITEM_AVAILABLE <= rSet.GetItemState( SID_GRFFILTER_SOLARIZE ) )
-        rSet.DisableItem( SID_GRFFILTER_SOLARIZE );
-};
-*/
 // --------------------------------------
 // - GraphicFilterDialog::PreviewWindow -
 // --------------------------------------
@@ -337,7 +61,7 @@ void GraphicFilterDialog::PreviewWindow::Paint( const Rectangle& rRect )
 
     const Size	aGrfSize( LogicToPixel( maGraphic.GetPrefSize(), maGraphic.GetPrefMapMode() ) );
     const Size	aOutSize( GetOutputSizePixel() );
-    const Point aGrfPos( ( aOutSize.Width() - aGrfSize.Width() ) >> 1, 
+    const Point aGrfPos( ( aOutSize.Width() - aGrfSize.Width() ) >> 1,
                          ( aOutSize.Height() - aGrfSize.Height() ) >> 1 );
 
     if( maGraphic.IsAnimated() )
@@ -369,16 +93,16 @@ GraphicFilterDialog::GraphicFilterDialog( Window* pParent, const ResId& rResId,
     mfScaleY		( 0.0 ),
     maSizePixel		( LogicToPixel( rGraphic.GetPrefSize(), rGraphic.GetPrefMapMode() ) ),
     maPreview       ( this, CUI_RES( CTL_PREVIEW ) ),
-    maFlParameter	( this, CUI_RES( FL_PARAMETER ) ),
     maBtnOK			( this, CUI_RES( BTN_OK ) ),
     maBtnCancel		( this, CUI_RES( BTN_CANCEL ) ),
-    maBtnHelp		( this, CUI_RES( BTN_HELP ) )
+    maBtnHelp		( this, CUI_RES( BTN_HELP ) ),
+    maFlParameter	( this, CUI_RES( FL_PARAMETER ) )
 {
     const Size	aPreviewSize( maPreview.GetOutputSizePixel() );
     Size		aGrfSize( maSizePixel );
 
     if( rGraphic.GetType() == GRAPHIC_BITMAP &&
-        aPreviewSize.Width() && aPreviewSize.Height() && 
+        aPreviewSize.Width() && aPreviewSize.Height() &&
         aGrfSize.Width() && aGrfSize.Height() )
     {
         const double fGrfWH = (double) aGrfSize.Width() / aGrfSize.Height();
@@ -446,7 +170,7 @@ IMPL_LINK( GraphicFilterDialog, ImplModifyHdl, void*, EMPTYARG )
 // ----------------
 
 GraphicFilterMosaic::GraphicFilterMosaic( Window* pParent, const Graphic& rGraphic,
-                                          USHORT nTileWidth, USHORT nTileHeight, BOOL bEnhanceEdges ) :
+                                          sal_uInt16 nTileWidth, sal_uInt16 nTileHeight, sal_Bool bEnhanceEdges ) :
     GraphicFilterDialog( pParent, CUI_RES( RID_SVX_GRFFILTER_DLG_MOSAIC ), rGraphic ),
     maFtWidth	( this, CUI_RES( DLG_FILTERMOSAIC_FT_WIDTH ) ),
     maMtrWidth	( this, CUI_RES( DLG_FILTERMOSAIC_MTR_WIDTH ) ),
@@ -468,6 +192,12 @@ GraphicFilterMosaic::GraphicFilterMosaic( Window* pParent, const Graphic& rGraph
     maCbxEdges.SetToggleHdl( GetModifyHdl() );
 
     maMtrWidth.GrabFocus();
+
+    maFtWidth.SetAccessibleRelationMemberOf(&maFlParameter);
+    maMtrWidth.SetAccessibleRelationMemberOf(&maFlParameter);
+    maFtHeight.SetAccessibleRelationMemberOf(&maFlParameter);
+    maMtrHeight.SetAccessibleRelationMemberOf(&maFlParameter);
+    maCbxEdges.SetAccessibleRelationMemberOf(&maFlParameter);
 }
 
 // -----------------------------------------------------------------------------
@@ -478,11 +208,11 @@ GraphicFilterMosaic::~GraphicFilterMosaic()
 
 // -----------------------------------------------------------------------------
 
-Graphic	GraphicFilterMosaic::GetFilteredGraphic( const Graphic& rGraphic, 
+Graphic	GraphicFilterMosaic::GetFilteredGraphic( const Graphic& rGraphic,
                                                  double fScaleX, double fScaleY )
 {
     Graphic			aRet;
-    const Size		aSize( Max( FRound( GetTileWidth() * fScaleX ), 1L ), 
+    const Size		aSize( Max( FRound( GetTileWidth() * fScaleX ), 1L ),
                            Max( FRound( GetTileHeight() * fScaleY ), 1L ) );
     BmpFilterParam	aParam( aSize );
 
@@ -519,7 +249,7 @@ Graphic	GraphicFilterMosaic::GetFilteredGraphic( const Graphic& rGraphic,
 // ------------------
 
 GraphicFilterSolarize::GraphicFilterSolarize( Window* pParent, const Graphic& rGraphic,
-                                              BYTE cGreyThreshold, BOOL bInvert ) :
+                                              sal_uInt8 cGreyThreshold, sal_Bool bInvert ) :
     GraphicFilterDialog	( pParent, CUI_RES( RID_SVX_GRFFILTER_DLG_SOLARIZE ), rGraphic ),
     maFtThreshold	( this, CUI_RES( DLG_FILTERSOLARIZE_FT_THRESHOLD ) ),
     maMtrThreshold	( this, CUI_RES( DLG_FILTERSOLARIZE_MTR_THRESHOLD ) ),
@@ -544,7 +274,7 @@ GraphicFilterSolarize::~GraphicFilterSolarize()
 
 // -----------------------------------------------------------------------------
 
-Graphic	GraphicFilterSolarize::GetFilteredGraphic( const Graphic& rGraphic, 
+Graphic	GraphicFilterSolarize::GetFilteredGraphic( const Graphic& rGraphic,
                                                    double /*fScaleX*/, double /*fScaleY*/ )
 {
     Graphic			aRet;
@@ -583,7 +313,7 @@ Graphic	GraphicFilterSolarize::GetFilteredGraphic( const Graphic& rGraphic,
 // ----------------------
 
 GraphicFilterSepia::GraphicFilterSepia( Window* pParent, const Graphic& rGraphic,
-                                        USHORT nSepiaPercent ) :
+                                        sal_uInt16 nSepiaPercent ) :
     GraphicFilterDialog	( pParent, CUI_RES( RID_SVX_GRFFILTER_DLG_SEPIA ), rGraphic ),
     maFtSepia		( this, CUI_RES( DLG_FILTERSEPIA_FT_SEPIA ) ),
     maMtrSepia		( this, CUI_RES( DLG_FILTERSEPIA_MTR_SEPIA ) )
@@ -604,7 +334,7 @@ GraphicFilterSepia::~GraphicFilterSepia()
 
 // -----------------------------------------------------------------------------
 
-Graphic	GraphicFilterSepia::GetFilteredGraphic( const Graphic& rGraphic, 
+Graphic	GraphicFilterSepia::GetFilteredGraphic( const Graphic& rGraphic,
                                                 double /*fScaleX*/, double /*fScaleY*/ )
 {
     Graphic			aRet;
@@ -633,7 +363,7 @@ Graphic	GraphicFilterSepia::GetFilteredGraphic( const Graphic& rGraphic,
 // -----------------------
 
 GraphicFilterPoster::GraphicFilterPoster( Window* pParent, const Graphic& rGraphic,
-                                          USHORT nPosterCount ) :
+                                          sal_uInt16 nPosterCount ) :
     GraphicFilterDialog	( pParent, CUI_RES( RID_SVX_GRFFILTER_DLG_POSTER ), rGraphic ),
     maFtPoster		( this, CUI_RES( DLG_FILTERPOSTER_FT_POSTER ) ),
     maNumPoster		( this, CUI_RES( DLG_FILTERPOSTER_NUM_POSTER ) )
@@ -655,11 +385,11 @@ GraphicFilterPoster::~GraphicFilterPoster()
 
 // -----------------------------------------------------------------------------
 
-Graphic	GraphicFilterPoster::GetFilteredGraphic( const Graphic& rGraphic, 
+Graphic	GraphicFilterPoster::GetFilteredGraphic( const Graphic& rGraphic,
                                                  double /*fScaleX*/, double /*fScaleY*/ )
 {
     Graphic			aRet;
-    const USHORT	nPosterCount = GetPosterColorCount();
+    const sal_uInt16	nPosterCount = GetPosterColorCount();
 
     if( rGraphic.IsAnimated() )
     {
@@ -715,15 +445,15 @@ GraphicFilterEmboss::~GraphicFilterEmboss()
 
 // -----------------------------------------------------------------------------
 
-Graphic	GraphicFilterEmboss::GetFilteredGraphic( const Graphic& rGraphic, 
+Graphic	GraphicFilterEmboss::GetFilteredGraphic( const Graphic& rGraphic,
                                                  double /*fScaleX*/, double /*fScaleY*/ )
 {
     Graphic	aRet;
-    USHORT	nAzim, nElev;
+    sal_uInt16	nAzim, nElev;
 
     switch( maCtlLight.GetActualRP() )
     {
-        default:	   DBG_ERROR("svx::GraphicFilterEmboss::GetFilteredGraphic(), unknown Reference Point!" );
+        default:	   OSL_FAIL("svx::GraphicFilterEmboss::GetFilteredGraphic(), unknown Reference Point!" );
         case( RP_LT ): nAzim = 4500,	nElev = 4500; break;
         case( RP_MT ): nAzim = 9000,	nElev = 4500; break;
         case( RP_RT ): nAzim = 13500,	nElev = 4500; break;
@@ -754,3 +484,5 @@ Graphic	GraphicFilterEmboss::GetFilteredGraphic( const Graphic& rGraphic,
 
     return aRet;
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
