@@ -112,13 +112,10 @@ STATIC_USTRING(FM_PROP_LABEL,C2U("Label"));
 STATIC_USTRING(FM_PROP_CONTROLSOURCE,C2U("DataField"));
 STATIC_USTRING(FM_PROP_NAME,C2U("Name"));
 STATIC_USTRING(FM_PROP_FORMATKEY,C2U("FormatKey"));
-#ifdef TF_SDBAPI
-#else // !TF_SDBAPI
 STATIC_USTRING(FM_PROP_EDITMODE,C2U("RecordMode"));
 STATIC_USTRING(FM_PROP_CURSORSOURCETYPE,C2U("DataSelectionType"));
 STATIC_USTRING(FM_PROP_CURSORSOURCE,C2U("DataSelection"));
 STATIC_USTRING(FM_PROP_DATASOURCE, C2U("DataSource"));
-#endif // !TF_SDBAPI
 STATIC_USTRING(FM_PROP_VALUE,C2U("Value"));
 STATIC_USTRING(FM_PROP_TEXT,C2U("Text"));
 
