@@ -66,27 +66,6 @@ component_getImplementationEnvironment(
     *ppEnvTypeName = CPPU_CURRENT_LANGUAGE_BINDING_NAME;
 }
 
-//---------------------------------------------------------------------------------------
-extern "C" SAL_DLLPUBLIC_EXPORT sal_Bool SAL_CALL component_writeInfo(
-                void* pServiceManager,
-                void* pRegistryKey
-            )
-{
-    if (pRegistryKey)
-    try
-    {
-        return ::preload::OModule::writeComponentInfos(
-            static_cast<XMultiServiceFactory*>(pServiceManager),
-            static_cast<XRegistryKey*>(pRegistryKey));
-    }
-    catch (InvalidRegistryException& )
-    {
-        OSL_ASSERT("preload::component_writeInfo: could not create a registry key (InvalidRegistryException) !");
-    }
-
-    return sal_False;
-}
-
 //---------------------------------------------------------------------------------------
 extern "C" SAL_DLLPUBLIC_EXPORT void* SAL_CALL component_getFactory(
                     const sal_Char* pImplementationName,
