@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -401,7 +402,7 @@ void SVGAttributeWriter::SetFontAttr( const Font& rFont )
         delete mpElemPaint, mpElemPaint = NULL;
         delete mpElemFont;
         mrExport.AddAttribute( XML_NAMESPACE_NONE, aXMLAttrStyle, GetFontStyle( maCurFont = rFont ) );
-        mpElemFont = new SvXMLElementExport( mrExport, XML_NAMESPACE_NONE, aXMLElemG, TRUE, TRUE );
+        mpElemFont = new SvXMLElementExport( mrExport, XML_NAMESPACE_NONE, aXMLElemG, sal_True, sal_True );
     }
 }
 
@@ -413,7 +414,7 @@ void SVGAttributeWriter::SetPaintAttr( const Color& rLineColor, const Color& rFi
     {
         delete mpElemPaint;
         mrExport.AddAttribute( XML_NAMESPACE_NONE, aXMLAttrStyle, GetPaintStyle( maCurLineColor = rLineColor, maCurFillColor = rFillColor ) );
-        mpElemPaint = new SvXMLElementExport( mrExport, XML_NAMESPACE_NONE, aXMLElemG, TRUE, TRUE );
+        mpElemPaint = new SvXMLElementExport( mrExport, XML_NAMESPACE_NONE, aXMLElemG, sal_True, sal_True );
     }
 }
 
@@ -518,11 +519,11 @@ void SVGActionWriter::ImplWriteLine( const Point& rPt1, const Point& rPt2, const
     if( pLineColor )
     {
         // !!! mrExport.AddAttribute( XML_NAMESPACE_NONE, ... )
-        DBG_ERROR( "SVGActionWriter::ImplWriteLine: Line color not implemented" );
+        OSL_FAIL( "SVGActionWriter::ImplWriteLine: Line color not implemented" );
     }
 
     {
-        SvXMLElementExport aElem( mrExport, XML_NAMESPACE_NONE, aXMLElemLine, TRUE, TRUE );
+        SvXMLElementExport aElem( mrExport, XML_NAMESPACE_NONE, aXMLElemLine, sal_True, sal_True );
     }
 }
 
@@ -549,7 +550,7 @@ void SVGActionWriter::ImplWriteRect( const Rectangle& rRect, long nRadX, long nR
         mrExport.AddAttribute( XML_NAMESPACE_NONE, aXMLAttrStyle, *pStyle );
 
     {
-        SvXMLElementExport aElem( mrExport, XML_NAMESPACE_NONE, aXMLElemRect, TRUE, TRUE );
+        SvXMLElementExport aElem( mrExport, XML_NAMESPACE_NONE, aXMLElemRect, sal_True, sal_True );
     }
 }
 
@@ -570,7 +571,7 @@ void SVGActionWriter::ImplWriteEllipse( const Point& rCenter, long nRadX, long n
         mrExport.AddAttribute( XML_NAMESPACE_NONE, aXMLAttrStyle, *pStyle );
 
     {
-        SvXMLElementExport aElem( mrExport, XML_NAMESPACE_NONE, aXMLElemEllipse, TRUE, TRUE );
+        SvXMLElementExport aElem( mrExport, XML_NAMESPACE_NONE, aXMLElemEllipse, sal_True, sal_True );
     }
 }
 
@@ -587,7 +588,7 @@ void SVGActionWriter::ImplWritePolygon( const Polygon& rPoly, sal_Bool bLineOnly
         {
             FastString					aStyle;
             FastString					aPoints;
-            USHORT						i = 0, nSize = rPoly.GetSize();
+            sal_uInt16						i = 0, nSize = rPoly.GetSize();
             const NMSP_RTL::OUString	aBlank( B2UCONST( " " ) );
 
             // points
@@ -626,7 +627,7 @@ void SVGActionWriter::ImplWritePolygon( const Polygon& rPoly, sal_Bool bLineOnly
 
             {
                 // write polyline/polygon element
-                SvXMLElementExport aElem( mrExport, XML_NAMESPACE_NONE, bLineOnly ? aXMLElemPolyLine : aXMLElemPolygon, TRUE, TRUE );
+                SvXMLElementExport aElem( mrExport, XML_NAMESPACE_NONE, bLineOnly ? aXMLElemPolyLine : aXMLElemPolygon, sal_True, sal_True );
             }
         }
     }
@@ -651,8 +652,8 @@ void SVGActionWriter::ImplWritePolyPolygon( const PolyPolygon& rPolyPoly, sal_Bo
 
             for( long i = 0, nCount = rPolyPoly.Count(); i < nCount; i++ )
             {
-                const Polygon&	rPoly = rPolyPoly[ (USHORT) i ];
-                USHORT			n = 1, nSize = rPoly.GetSize();
+                const Polygon&	rPoly = rPolyPoly[ (sal_uInt16) i ];
+                sal_uInt16			n = 1, nSize = rPoly.GetSize();
 
                 if( nSize > 1 )
                 {
@@ -716,7 +717,7 @@ void SVGActionWriter::ImplWritePolyPolygon( const PolyPolygon& rPolyPoly, sal_Bo
             mrExport.AddAttribute( XML_NAMESPACE_NONE, aXMLAttrD, aPathData.GetString() );				
             {
                 // write polyline/polygon element
-                SvXMLElementExport aElem( mrExport, XML_NAMESPACE_NONE, aXMLElemPath, TRUE, TRUE );
+                SvXMLElementExport aElem( mrExport, XML_NAMESPACE_NONE, aXMLElemPath, sal_True, sal_True );
             }
         }
     }
@@ -729,7 +730,7 @@ void SVGActionWriter::ImplWriteGradientEx( const PolyPolygon& rPolyPoly, const G
 {
     if( rPolyPoly.Count() )
     {
-        SvXMLElementExport	aElemG( mrExport, XML_NAMESPACE_NONE, aXMLElemG, TRUE, TRUE );
+        SvXMLElementExport	aElemG( mrExport, XML_NAMESPACE_NONE, aXMLElemG, sal_True, sal_True );
         FastString			aClipId;
         FastString			aClipStyle;
 
@@ -737,12 +738,12 @@ void SVGActionWriter::ImplWriteGradientEx( const PolyPolygon& rPolyPoly, const G
         aClipId += NMSP_RTL::OUString::valueOf( ImplGetNextClipId() );
 
         {
-            SvXMLElementExport aElemDefs( mrExport, XML_NAMESPACE_NONE, aXMLElemDefs, TRUE, TRUE );
+            SvXMLElementExport aElemDefs( mrExport, XML_NAMESPACE_NONE, aXMLElemDefs, sal_True, sal_True );
 
             mrExport.AddAttribute( XML_NAMESPACE_NONE, aXMLAttrId, aClipId.GetString() );
 
             {
-                SvXMLElementExport aElemClipPath( mrExport, XML_NAMESPACE_NONE, aXMLElemClipPath, TRUE, TRUE );
+                SvXMLElementExport aElemClipPath( mrExport, XML_NAMESPACE_NONE, aXMLElemClipPath, sal_True, sal_True );
                 ImplWritePolyPolygon( rPolyPoly, sal_False );
             }
         }
@@ -756,7 +757,7 @@ void SVGActionWriter::ImplWriteGradientEx( const PolyPolygon& rPolyPoly, const G
 
         {
             GDIMetaFile			aTmpMtf;
-            SvXMLElementExport	aElemG2( mrExport, XML_NAMESPACE_NONE, aXMLElemG, TRUE, TRUE );
+            SvXMLElementExport	aElemG2( mrExport, XML_NAMESPACE_NONE, aXMLElemG, sal_True, sal_True );
 
             mpVDev->AddGradientActions( rPolyPoly.GetBoundRect(), rGradient, aTmpMtf );
             ImplWriteActions( aTmpMtf, pStyle );
@@ -771,7 +772,7 @@ void SVGActionWriter::ImplWriteText( const Point& rPos, const String& rText,
                                      const NMSP_RTL::OUString* pStyle )
 {
     String	aText( rText ); aText.EraseLeadingChars( ' ' );
-    UINT32	nLen = aText.Len(), i;
+    sal_uInt32	nLen = aText.Len(), i;
 
     if( nLen )
     {
@@ -795,7 +796,7 @@ void SVGActionWriter::ImplWriteText( const Point& rPos, const String& rText,
 
         if( nLen > 1 )
         {
-            aNormSize.Width() = pDX[ nLen - 2 ] + mpVDev->GetTextWidth( aText.GetChar(  (USHORT) nLen - 1 ) );
+            aNormSize.Width() = pDX[ nLen - 2 ] + mpVDev->GetTextWidth( aText.GetChar(  (sal_uInt16) nLen - 1 ) );
 
             if( nWidth && aNormSize.Width() && ( nWidth != aNormSize.Width() ) )
             {
@@ -841,19 +842,19 @@ void SVGActionWriter::ImplWriteText( const Point& rPos, const String& rText,
         {
             String aTransform;
 
-            aTransform = NMSP_RTL::OUString::createFromAscii( "translate" );
+            aTransform = NMSP_RTL::OUString(RTL_CONSTASCII_USTRINGPARAM("translate"));
             aTransform += '(';
             aTransform += String( GetValueString( aPt.X(), mbDoublePoints ) );
             aTransform += ',';
             aTransform += String( GetValueString( aPt.Y(), mbDoublePoints ) );
             aTransform += ')';
 
-            aTransform += String( NMSP_RTL::OUString::createFromAscii( " rotate" ) );
+            aTransform += String( NMSP_RTL::OUString(RTL_CONSTASCII_USTRINGPARAM(" rotate")) );
             aTransform += '(';
             aTransform += String( NMSP_RTL::OUString::valueOf( rFont.GetOrientation() * -0.1 ) );
             aTransform += ')';
 
-            aTransform += String( NMSP_RTL::OUString::createFromAscii( " translate" ) );
+            aTransform += String( NMSP_RTL::OUString(RTL_CONSTASCII_USTRINGPARAM(" translate")) );
             aTransform += '(';
             aTransform += String( GetValueString( -aPt.X(), mbDoublePoints ) );
             aTransform += ',';
@@ -861,7 +862,7 @@ void SVGActionWriter::ImplWriteText( const Point& rPos, const String& rText,
             aTransform += ')';
 
             mrExport.AddAttribute( XML_NAMESPACE_NONE, aXMLAttrTransform, aTransform );
-            pTransform = new SvXMLElementExport( mrExport, XML_NAMESPACE_NONE, aXMLElemG, TRUE, TRUE );
+            pTransform = new SvXMLElementExport( mrExport, XML_NAMESPACE_NONE, aXMLElemG, sal_True, sal_True );
         }
 
         // add additional style if requested
@@ -872,7 +873,7 @@ void SVGActionWriter::ImplWriteText( const Point& rPos, const String& rText,
 #ifdef _SVG_USE_TSPANS
         if( pDXArray )
         {
-            SvXMLElementExport			aElem( mrExport, XML_NAMESPACE_NONE, aXMLElemText, TRUE, TRUE );
+            SvXMLElementExport			aElem( mrExport, XML_NAMESPACE_NONE, aXMLElemText, sal_True, sal_True );
             FastString					aTSpanX;
             const NMSP_RTL::OUString	aSpace( ' ' );
             long						i, nX, nCount;
@@ -894,7 +895,7 @@ void SVGActionWriter::ImplWriteText( const Point& rPos, const String& rText,
                 {
                     try
                     {
-                        SvXMLElementExport aElem( mrExport, XML_NAMESPACE_NONE, aXMLElemTSpan, TRUE, TRUE );
+                        SvXMLElementExport aElem( mrExport, XML_NAMESPACE_NONE, aXMLElemTSpan, sal_True, sal_True );
                         mrExport.GetDocHandler()->characters( NMSP_RTL::OUString( UniString( aText ) ) );
                     }
                     catch( ::com::sun::star::xml::sax::SAXException&  )
@@ -912,7 +913,7 @@ void SVGActionWriter::ImplWriteText( const Point& rPos, const String& rText,
 
             try
             {
-                SvXMLElementExport aElem( mrExport, XML_NAMESPACE_NONE, aXMLElemText, TRUE, TRUE );
+                SvXMLElementExport aElem( mrExport, XML_NAMESPACE_NONE, aXMLElemText, sal_True, sal_True );
                 mrExport.GetDocHandler()->characters( NMSP_RTL::OUString( UniString( aText ) ) );
             }
             catch( ::com::sun::star::xml::sax::SAXException&  )
@@ -938,7 +939,7 @@ void SVGActionWriter::ImplWriteText( const Point& rPos, const String& rText,
                 aPoly[ 2 ].X() = aPoly[ 1 ].X(); aPoly[ 2 ].Y() = aPoly[ 0 ].Y() + nLineHeight - 1;
                 aPoly[ 3 ].X() = aPoly[ 0 ].X(); aPoly[ 3 ].Y() = aPoly[ 2 ].Y();
                         
-                ImplWritePolygon( aPoly, FALSE );
+                ImplWritePolygon( aPoly, sal_False );
             }
 
             if( rFont.GetUnderline() )
@@ -950,7 +951,7 @@ void SVGActionWriter::ImplWriteText( const Point& rPos, const String& rText,
                 aPoly[ 2 ].X() = aPoly[ 1 ].X(); aPoly[ 2 ].Y() = aPoly[ 0 ].Y() + nLineHeight - 1;
                 aPoly[ 3 ].X() = aPoly[ 0 ].X(); aPoly[ 3 ].Y() = aPoly[ 2 ].Y();
                         
-                ImplWritePolygon( aPoly, FALSE );
+                ImplWritePolygon( aPoly, sal_False );
             }
         }
 
@@ -1049,10 +1050,10 @@ void SVGActionWriter::ImplWriteActions( const GDIMetaFile& rMtf, const NMSP_RTL:
 {
     ImplAcquireContext();
 
-    for( ULONG i = 0, nCount = rMtf.GetActionCount(); i < nCount; i++ )
+    for( sal_uLong i = 0, nCount = rMtf.GetActionCount(); i < nCount; i++ )
     {
         const MetaAction*	pAction = rMtf.GetAction( i );
-        const USHORT		nType = pAction->GetType();
+        const sal_uInt16		nType = pAction->GetType();
 
         switch( nType )
         {
@@ -1253,7 +1254,7 @@ void SVGActionWriter::ImplWriteActions( const GDIMetaFile& rMtf, const NMSP_RTL:
                 const GDIMetaFile		aGDIMetaFile( pA->GetSubstitute() );
                 sal_Bool				bFound = sal_False;
 
-                for( ULONG j = 0, nCount2 = aGDIMetaFile.GetActionCount(); ( j < nCount2 ) && !bFound; j++ )
+                for( sal_uLong j = 0, nCount2 = aGDIMetaFile.GetActionCount(); ( j < nCount2 ) && !bFound; j++ )
                 {
                     const MetaAction* pSubstAct = aGDIMetaFile.GetAction( j );
                     
@@ -1448,7 +1449,7 @@ void SVGActionWriter::ImplWriteActions( const GDIMetaFile& rMtf, const NMSP_RTL:
             default :
                 ByteString aDbgOut( "SVGActionWriter::ImplWriteActions: unsupported MetaAction #" );
                 aDbgOut.Append( ByteString::CreateFromInt32( nType ) );
-                DBG_ERROR( aDbgOut.GetBuffer() );
+                OSL_FAIL( aDbgOut.GetBuffer() );
             break;
 #endif
         }
@@ -1456,3 +1457,5 @@ void SVGActionWriter::ImplWriteActions( const GDIMetaFile& rMtf, const NMSP_RTL:
 
     ImplReleaseContext();
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
