@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -45,18 +46,15 @@
 #include <usr/reflserv.hxx>  // for EXTERN_SERVICE_CALLTYPE
 #include <usr/weak.hxx>      // OWeakObject
 
-#include <vos/conditn.hxx>
-#include <vos/mutex.hxx>
-#include <vos/thread.hxx>
+#include <osl/conditn.hxx>
+#include <osl/mutex.hxx>
+#include <osl/thread.hxx>
 
 #include <string.h>
 
 #include "testfactreg.hxx"
 
-#ifndef _VOS_NO_NAMESPACE
-using namespace vos;
 using namespace usr;
-#endif
 
 #define DATASTREAM_TEST_MAX_HANDLE 1
 
@@ -1070,3 +1068,4 @@ UString 	OObjectStreamTest_getImplementationName( int i) THROWS( () )
 }
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
