@@ -1,7 +1,8 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -34,18 +35,22 @@
 #include <com/sun/star/io/XOutputStream.hpp>
 #include <com/sun/star/io/XStream.hpp>
 #include <com/sun/star/io/XSeekable.hpp>
+#include <com/sun/star/xml/crypto/DigestID.hpp>
+#include <com/sun/star/xml/crypto/CipherID.hpp>
 
 
 #include <ZipPackageStream.hxx>
 #include <ZipPackage.hxx>
 #include <ZipFile.hxx>
 #include <EncryptedDataHeader.hxx>
-#include <vos/diagnose.hxx>
+#include <osl/diagnose.h>
 #include "wrapstreamforshare.hxx"
 
 #include <comphelper/seekableinput.hxx>
 #include <comphelper/storagehelper.hxx>
 
+#include <rtl/instance.hxx>
+
 #include <PackageConstants.hxx>
 
 using namespace com::sun::star::packages::zip::ZipConstants;
@@ -54,28 +59,36 @@ using namespace com::sun::star::uno;
 using namespace com::sun::star::lang;
 using namespace com::sun::star;
 using namespace cppu;
-using namespace rtl;
 
-Sequence < sal_Int8 > ZipPackageStream::aImplementationId = Sequence < sal_Int8 > ();
+using rtl::OUString;
+namespace { struct lcl_CachedImplId : public rtl::Static< Sequence < sal_Int8 >, lcl_CachedImplId > {}; }
 
+const ::com::sun::star::uno::Sequence < sal_Int8 >& ZipPackageStream::static_getImplementationId()
+{
+    return lcl_CachedImplId::get();
+}
 
 ZipPackageStream::ZipPackageStream ( ZipPackage & rNewPackage,
                                     const Reference< XMultiServiceFactory >& xFactory,
-                                    sal_Bool bAllowRemoveOnInsert ) 
+                                    sal_Bool bAllowRemoveOnInsert )
 : m_xFactory( xFactory )
 , rZipPackage(rNewPackage)
 , bToBeCompressed ( sal_True )
 , bToBeEncrypted ( sal_False )
 , bHaveOwnKey ( sal_False )
 , bIsEncrypted ( sal_False )
-, xEncryptionData ( )
+, m_nImportedStartKeyAlgorithm( 0 )
+, m_nImportedEncryptionAlgorithm( 0 )
+, m_nImportedChecksumAlgorithm( 0 )
+, m_nImportedDerivedKeySize( 0 )
 , m_nStreamMode( PACKAGE_STREAM_NOTSET )
 , m_nMagicalHackPos( 0 )
 , m_nMagicalHackSize( 0 )
 , m_bHasSeekable( sal_False )
 , m_bCompressedIsSetFromOutside( sal_False )
 , m_bFromManifest( sal_False )
-{ 
+, m_bUseWinEncoding( false )
+{
     OSL_ENSURE( m_xFactory.is(), "No factory is provided to ZipPackageStream!\n" );
 
     this->mbAllowRemoveOnInsert = bAllowRemoveOnInsert;
@@ -92,10 +105,9 @@ ZipPackageStream::ZipPackageStream ( ZipPackage & rNewPackage,
     aEntry.nPathLen		= -1;
     aEntry.nExtraLen	= -1;
 
-    if ( !aImplementationId.getLength() )
-        {
-            aImplementationId = getImplementationId();
-        }
+    Sequence < sal_Int8 > &rCachedImplId = lcl_CachedImplId::get();
+    if ( !rCachedImplId.getLength() )
+        rCachedImplId = getImplementationId();
 }
 
 ZipPackageStream::~ZipPackageStream( void )
@@ -132,7 +144,7 @@ void ZipPackageStream::CloseOwnStreamIfAny()
 }
 
 //--------------------------------------------------------------------------
-uno::Reference< io::XInputStream >& ZipPackageStream::GetOwnSeekStream()
+uno::Reference< io::XInputStream > ZipPackageStream::GetOwnSeekStream()
 {
     if ( !m_bHasSeekable && xStream.is() )
     {
@@ -158,7 +170,7 @@ uno::Reference< io::XInputStream > ZipPackageStream::GetRawEncrStreamNoHeaderCop
     if ( m_nStreamMode != PACKAGE_STREAM_RAW || !GetOwnSeekStream().is() )
         throw io::IOException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX ) ), uno::Reference< uno::XInterface >() );
 
-    if ( xEncryptionData.isEmpty() )
+    if ( m_xBaseEncryptionData.is() )
         throw ZipIOException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX "Encrypted stream without encryption data!\n" ) ),
                             Reference< XInterface >() );
 
@@ -168,11 +180,11 @@ uno::Reference< io::XInputStream > ZipPackageStream::GetRawEncrStreamNoHeaderCop
                             Reference< XInterface >() );
 
     // skip header
-    xSeek->seek( n_ConstHeaderSize + xEncryptionData->aInitVector.getLength() + 
-                    xEncryptionData->aSalt.getLength() + xEncryptionData->aDigest.getLength() );
+    xSeek->seek( n_ConstHeaderSize + getInitialisationVector().getLength() +
+                    getSalt().getLength() + getDigest().getLength() );
 
     // create temporary stream
-    uno::Reference < io::XOutputStream > xTempOut( 
+    uno::Reference < io::XOutputStream > xTempOut(
                         m_xFactory->createInstance( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.io.TempFile" ) ) ),
                         uno::UNO_QUERY );
     uno::Reference < io::XInputStream > xTempIn( xTempOut, UNO_QUERY );
@@ -188,6 +200,85 @@ uno::Reference< io::XInputStream > ZipPackageStream::GetRawEncrStreamNoHeaderCop
     return xTempIn;
 }
 
+//--------------------------------------------------------------------------
+sal_Int32 ZipPackageStream::GetEncryptionAlgorithm() const
+{
+    return m_nImportedEncryptionAlgorithm ? m_nImportedEncryptionAlgorithm : rZipPackage.GetEncAlgID();
+}
+
+//--------------------------------------------------------------------------
+sal_Int32 ZipPackageStream::GetBlockSize() const
+{
+    return GetEncryptionAlgorithm() == ::com::sun::star::xml::crypto::CipherID::AES_CBC_W3C_PADDING ? 16 : 8;
+}
+
+//--------------------------------------------------------------------------
+::rtl::Reference< EncryptionData > ZipPackageStream::GetEncryptionData( bool bUseWinEncoding )
+{
+    ::rtl::Reference< EncryptionData > xResult;
+    if ( m_xBaseEncryptionData.is() )
+        xResult = new EncryptionData(
+            *m_xBaseEncryptionData,
+            GetEncryptionKey( bUseWinEncoding ),
+            GetEncryptionAlgorithm(),
+            m_nImportedChecksumAlgorithm ? m_nImportedChecksumAlgorithm : rZipPackage.GetChecksumAlgID(),
+            m_nImportedDerivedKeySize ? m_nImportedDerivedKeySize : rZipPackage.GetDefaultDerivedKeySize(),
+            GetStartKeyGenID() );
+
+    return xResult;
+}
+
+//--------------------------------------------------------------------------
+void ZipPackageStream::SetBaseEncryptionData( const ::rtl::Reference< BaseEncryptionData >& xData )
+{
+    m_xBaseEncryptionData = xData;
+}
+
+//--------------------------------------------------------------------------
+uno::Sequence< sal_Int8 > ZipPackageStream::GetEncryptionKey( bool bUseWinEncoding )
+{
+    uno::Sequence< sal_Int8 > aResult;
+    sal_Int32 nKeyGenID = GetStartKeyGenID();
+    bUseWinEncoding = ( bUseWinEncoding || m_bUseWinEncoding );
+
+    if ( bHaveOwnKey && m_aStorageEncryptionKeys.getLength() )
+    {
+        ::rtl::OUString aNameToFind;
+        if ( nKeyGenID == xml::crypto::DigestID::SHA256 )
+            aNameToFind = PACKAGE_ENCRYPTIONDATA_SHA256UTF8;
+        else if ( nKeyGenID == xml::crypto::DigestID::SHA1 )
+        {
+            aNameToFind = bUseWinEncoding ? PACKAGE_ENCRYPTIONDATA_SHA1MS1252 : PACKAGE_ENCRYPTIONDATA_SHA1UTF8;
+        }
+        else
+            throw uno::RuntimeException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX "No expected key is provided!" ) ), uno::Reference< uno::XInterface >() );
+
+        for ( sal_Int32 nInd = 0; nInd < m_aStorageEncryptionKeys.getLength(); nInd++ )
+            if ( m_aStorageEncryptionKeys[nInd].Name.equals( aNameToFind ) )
+                m_aStorageEncryptionKeys[nInd].Value >>= aResult;
+
+        // empty keys are not allowed here
+        // so it is not important whether there is no key, or the key is empty, it is an error
+        if ( !aResult.getLength() )
+            throw uno::RuntimeException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX "No expected key is provided!" ) ), uno::Reference< uno::XInterface >() );
+    }
+    else
+        aResult = m_aEncryptionKey;
+
+    if ( !aResult.getLength() || !bHaveOwnKey )
+        aResult = rZipPackage.GetEncryptionKey();
+
+    return aResult;
+}
+
+//--------------------------------------------------------------------------
+sal_Int32 ZipPackageStream::GetStartKeyGenID()
+{
+    // generally should all the streams use the same Start Key
+    // but if raw copy without password takes place, we should preserve the imported algorithm
+    return m_nImportedStartKeyAlgorithm ? m_nImportedStartKeyAlgorithm : rZipPackage.GetStartKeyGenID();
+}
+
 //--------------------------------------------------------------------------
 Reference< io::XInputStream > ZipPackageStream::TryToGetRawFromDataStream( sal_Bool bAddHeaderForEncr )
 {
@@ -195,11 +286,10 @@ Reference< io::XInputStream > ZipPackageStream::TryToGetRawFromDataStream( sal_B
         throw packages::NoEncryptionException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX ) ), uno::Reference< uno::XInterface >() );
 
     Sequence< sal_Int8 > aKey;
-    
+
     if ( bToBeEncrypted )
     {
-        aKey = ( xEncryptionData.isEmpty() || !bHaveOwnKey ) ? rZipPackage.getEncryptionKey() : 
-                                                                                xEncryptionData->aKey;
+        aKey = GetEncryptionKey();
         if ( !aKey.getLength() )
             throw packages::NoEncryptionException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX ) ), uno::Reference< uno::XInterface >() );
     }
@@ -207,30 +297,30 @@ Reference< io::XInputStream > ZipPackageStream::TryToGetRawFromDataStream( sal_B
     try
     {
         // create temporary file
-        uno::Reference < io::XStream > xTempStream( 
+        uno::Reference < io::XStream > xTempStream(
                             m_xFactory->createInstance ( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.io.TempFile" ) ) ),
                             uno::UNO_QUERY );
         if ( !xTempStream.is() )
             throw io::IOException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX ) ), uno::Reference< uno::XInterface >() );
-    
+
         // create a package based on it
         ZipPackage* pPackage = new ZipPackage( m_xFactory );
         Reference< XSingleServiceFactory > xPackageAsFactory( static_cast< XSingleServiceFactory* >( pPackage ) );
         if ( !xPackageAsFactory.is() )
             throw RuntimeException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX ) ), uno::Reference< uno::XInterface >() );
-    
+
         Sequence< Any > aArgs( 1 );
         aArgs[0] <<= xTempStream;
         pPackage->initialize( aArgs );
-    
+
         // create a new package stream
         Reference< XDataSinkEncrSupport > xNewPackStream( xPackageAsFactory->createInstance(), UNO_QUERY );
         if ( !xNewPackStream.is() )
             throw RuntimeException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX ) ), uno::Reference< uno::XInterface >() );
-    
+
         xNewPackStream->setDataStream( static_cast< io::XInputStream* >(
                                                     new WrapStreamForShare( GetOwnSeekStream(), rZipPackage.GetSharedMutexRef() ) ) );
-    
+
         Reference< XPropertySet > xNewPSProps( xNewPackStream, UNO_QUERY );
         if ( !xNewPSProps.is() )
             throw RuntimeException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX ) ), uno::Reference< uno::XInterface >() );
@@ -240,7 +330,7 @@ Reference< io::XInputStream > ZipPackageStream::TryToGetRawFromDataStream( sal_B
         xNewPSProps->setPropertyValue( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Compressed" ) ), makeAny( bToBeCompressed ) );
         if ( bToBeEncrypted )
         {
-            xNewPSProps->setPropertyValue( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "EncryptionKey" ) ), makeAny( aKey ) );
+            xNewPSProps->setPropertyValue( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ENCRYPTION_KEY_PROPERTY ) ), makeAny( aKey ) );
             xNewPSProps->setPropertyValue( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Encrypted" ) ), makeAny( sal_True ) );
         }
 
@@ -251,7 +341,7 @@ Reference< io::XInputStream > ZipPackageStream::TryToGetRawFromDataStream( sal_B
         Reference< container::XNameContainer > xRootNameContainer( xTunnel, UNO_QUERY );
         if ( !xRootNameContainer.is() )
             throw RuntimeException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX ) ), uno::Reference< uno::XInterface >() );
-    
+
         Reference< XUnoTunnel > xNPSTunnel( xNewPackStream, UNO_QUERY );
         xRootNameContainer->insertByName( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "dummy" ) ), makeAny( xNPSTunnel ) );
 
@@ -264,9 +354,9 @@ Reference< io::XInputStream > ZipPackageStream::TryToGetRawFromDataStream( sal_B
             xInRaw = xNewPackStream->getRawStream();
         else
             xInRaw = xNewPackStream->getPlainRawStream();
-        
+
         // create another temporary file
-        uno::Reference < io::XOutputStream > xTempOut( 
+        uno::Reference < io::XOutputStream > xTempOut(
                             m_xFactory->createInstance ( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.io.TempFile" ) ) ),
                             uno::UNO_QUERY );
         uno::Reference < io::XInputStream > xTempIn( xTempOut, UNO_QUERY );
@@ -300,7 +390,7 @@ Reference< io::XInputStream > ZipPackageStream::TryToGetRawFromDataStream( sal_B
 
     throw io::IOException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX ) ), uno::Reference< uno::XInterface >() );
 }
-    
+
 //--------------------------------------------------------------------------
 sal_Bool ZipPackageStream::ParsePackageRawStream()
 {
@@ -311,11 +401,11 @@ sal_Bool ZipPackageStream::ParsePackageRawStream()
 
     sal_Bool bOk = sal_False;
 
-    vos::ORef < EncryptionData > xTempEncrData;
+    rtl::Reference < BaseEncryptionData > xTempEncrData;
     sal_Int32 nMagHackSize = 0;
     Sequence < sal_Int8 > aHeader ( 4 );
 
-    try 
+    try
     {
         if ( GetOwnSeekStream()->readBytes ( aHeader, 4 ) == 4 )
         {
@@ -327,20 +417,28 @@ sal_Bool ZipPackageStream::ParsePackageRawStream()
             if ( nHeader == n_ConstHeader )
             {
                 // this is one of our god-awful, but extremely devious hacks, everyone cheer
-                xTempEncrData = new EncryptionData;
-    
+                xTempEncrData = new BaseEncryptionData;
+
                 ::rtl::OUString aMediaType;
-                if ( ZipFile::StaticFillData ( xTempEncrData, nMagHackSize, aMediaType, GetOwnSeekStream() ) )
+                sal_Int32 nEncAlgorithm = 0;
+                sal_Int32 nChecksumAlgorithm = 0;
+                sal_Int32 nDerivedKeySize = 0;
+                sal_Int32 nStartKeyGenID = 0;
+                if ( ZipFile::StaticFillData( xTempEncrData, nEncAlgorithm, nChecksumAlgorithm, nDerivedKeySize, nStartKeyGenID, nMagHackSize, aMediaType, GetOwnSeekStream() ) )
                 {
                     // We'll want to skip the data we've just read, so calculate how much we just read
                     // and remember it
-                    m_nMagicalHackPos = n_ConstHeaderSize + xTempEncrData->aSalt.getLength() 
-                                                        + xTempEncrData->aInitVector.getLength()
-                                                        + xTempEncrData->aDigest.getLength()
+                    m_nMagicalHackPos = n_ConstHeaderSize + xTempEncrData->m_aSalt.getLength()
+                                                        + xTempEncrData->m_aInitVector.getLength()
+                                                        + xTempEncrData->m_aDigest.getLength()
                                                         + aMediaType.getLength() * sizeof( sal_Unicode );
+                    m_nImportedEncryptionAlgorithm = nEncAlgorithm;
+                    m_nImportedChecksumAlgorithm = nChecksumAlgorithm;
+                    m_nImportedDerivedKeySize = nDerivedKeySize;
+                    m_nImportedStartKeyAlgorithm = nStartKeyGenID;
                     m_nMagicalHackSize = nMagHackSize;
                     sMediaType = aMediaType;
-    
+
                     bOk = sal_True;
                 }
             }
@@ -356,7 +454,7 @@ sal_Bool ZipPackageStream::ParsePackageRawStream()
         return sal_False;
     }
 
-    xEncryptionData = xTempEncrData;
+    m_xBaseEncryptionData = xTempEncrData;
     SetIsEncrypted ( sal_True );
     // it's already compressed and encrypted
     bToBeEncrypted = bToBeCompressed = sal_False;
@@ -365,7 +463,7 @@ sal_Bool ZipPackageStream::ParsePackageRawStream()
 }
 
 void ZipPackageStream::SetPackageMember( sal_Bool bNewValue )
-{ 
+{
     if ( bNewValue )
     {
         m_nStreamMode = PACKAGE_STREAM_PACKAGEMEMBER;
@@ -378,11 +476,12 @@ void ZipPackageStream::SetPackageMember( sal_Bool bNewValue )
 
 // XActiveDataSink
 //--------------------------------------------------------------------------
-void SAL_CALL ZipPackageStream::setInputStream( const Reference< io::XInputStream >& aStream ) 
-        throw(RuntimeException)
+void SAL_CALL ZipPackageStream::setInputStream( const Reference< io::XInputStream >& aStream )
+        throw( RuntimeException )
 {
     // if seekable access is required the wrapping will be done on demand
     xStream = aStream;
+    m_nImportedEncryptionAlgorithm = 0;
     m_bHasSeekable = sal_False;
     SetPackageMember ( sal_False );
     aEntry.nTime = -1;
@@ -391,15 +490,13 @@ void SAL_CALL ZipPackageStream::setInputStream( const Reference< io::XInputStrea
 
 //--------------------------------------------------------------------------
 Reference< io::XInputStream > SAL_CALL ZipPackageStream::getRawData()
-        throw(RuntimeException)
+        throw( RuntimeException )
 {
     try
     {
         if (IsPackageMember())
         {
-            if ( !xEncryptionData.isEmpty() && !bHaveOwnKey )
-                xEncryptionData->aKey = rZipPackage.getEncryptionKey();
-            return rZipPackage.getZipFile().getRawData( aEntry, xEncryptionData, bIsEncrypted, rZipPackage.GetSharedMutexRef() );
+            return rZipPackage.getZipFile().getRawData( aEntry, GetEncryptionData(), bIsEncrypted, rZipPackage.GetSharedMutexRef() );
         }
         else if ( GetOwnSeekStream().is() )
         {
@@ -410,27 +507,25 @@ Reference< io::XInputStream > SAL_CALL ZipPackageStream::getRawData()
     }
     catch (ZipException &)//rException)
     {
-        VOS_ENSURE( 0, "ZipException thrown");//rException.Message);
+        OSL_FAIL( "ZipException thrown");//rException.Message);
         return Reference < io::XInputStream > ();
     }
     catch (Exception &)
     {
-        VOS_ENSURE( 0, "Exception is thrown during stream wrapping!\n");
+        OSL_FAIL( "Exception is thrown during stream wrapping!\n");
         return Reference < io::XInputStream > ();
     }
 }
 
 //--------------------------------------------------------------------------
-Reference< io::XInputStream > SAL_CALL ZipPackageStream::getInputStream(  ) 
+Reference< io::XInputStream > SAL_CALL ZipPackageStream::getInputStream(  )
         throw(RuntimeException)
 {
     try
     {
         if (IsPackageMember())
         {
-            if ( !xEncryptionData.isEmpty() && !bHaveOwnKey )
-                xEncryptionData->aKey = rZipPackage.getEncryptionKey();
-            return rZipPackage.getZipFile().getInputStream( aEntry, xEncryptionData, bIsEncrypted, rZipPackage.GetSharedMutexRef() );
+            return rZipPackage.getZipFile().getInputStream( aEntry, GetEncryptionData(), bIsEncrypted, rZipPackage.GetSharedMutexRef() );
         }
         else if ( GetOwnSeekStream().is() )
         {
@@ -441,19 +536,19 @@ Reference< io::XInputStream > SAL_CALL ZipPackageStream::getInputStream(  )
     }
     catch (ZipException &)//rException)
     {
-        VOS_ENSURE( 0,"ZipException thrown");//rException.Message);
+        OSL_FAIL( "ZipException thrown");//rException.Message);
         return Reference < io::XInputStream > ();
     }
     catch (Exception &)
     {
-        VOS_ENSURE( 0, "Exception is thrown during stream wrapping!\n");
+        OSL_FAIL( "Exception is thrown during stream wrapping!\n");
         return Reference < io::XInputStream > ();
     }
 }
 
 // XDataSinkEncrSupport
 //--------------------------------------------------------------------------
-Reference< io::XInputStream > SAL_CALL ZipPackageStream::getDataStream()
+uno::Reference< io::XInputStream > SAL_CALL ZipPackageStream::getDataStream()
         throw ( packages::WrongPasswordException,
                 io::IOException,
                 RuntimeException )
@@ -466,18 +561,28 @@ Reference< io::XInputStream > SAL_CALL ZipPackageStream::getDataStream()
     if ( m_nStreamMode == PACKAGE_STREAM_DETECT )
         throw packages::zip::ZipIOException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX ) ), uno::Reference< uno::XInterface >() );
 
-    if ( !xEncryptionData.isEmpty() && !bHaveOwnKey )
-        xEncryptionData->aKey = rZipPackage.getEncryptionKey();
-
     if (IsPackageMember())
     {
-        if ( !xEncryptionData.isEmpty() && !bHaveOwnKey )
-            xEncryptionData->aKey = rZipPackage.getEncryptionKey();
-
-        return rZipPackage.getZipFile().getDataStream( aEntry, xEncryptionData, bIsEncrypted, rZipPackage.GetSharedMutexRef() );
+        uno::Reference< io::XInputStream > xResult;
+        try
+        {
+            xResult = rZipPackage.getZipFile().getDataStream( aEntry, GetEncryptionData(), bIsEncrypted, rZipPackage.GetSharedMutexRef() );
+        }
+        catch( packages::WrongPasswordException& )
+        {
+            // workaround for the encrypted documents generated with the old OOo1.x bug.
+            if ( rZipPackage.GetStartKeyGenID() == xml::crypto::DigestID::SHA1 && !m_bUseWinEncoding )
+            {
+                xResult = rZipPackage.getZipFile().getDataStream( aEntry, GetEncryptionData( true ), bIsEncrypted, rZipPackage.GetSharedMutexRef() );
+                m_bUseWinEncoding = true;
+            }
+            else
+                throw;
+        }
+        return xResult;
     }
     else if ( m_nStreamMode == PACKAGE_STREAM_RAW )
-        return ZipFile::StaticGetDataFromRawStream( GetOwnSeekStream(), xEncryptionData );
+        return ZipFile::StaticGetDataFromRawStream( m_xFactory, GetOwnSeekStream(), GetEncryptionData() );
     else if ( GetOwnSeekStream().is() )
     {
         return new WrapStreamForShare( GetOwnSeekStream(), rZipPackage.GetSharedMutexRef() );
@@ -502,10 +607,10 @@ Reference< io::XInputStream > SAL_CALL ZipPackageStream::getRawStream()
 
     if (IsPackageMember())
     {
-        if ( !bIsEncrypted || xEncryptionData.isEmpty() )
+        if ( !bIsEncrypted || !GetEncryptionData().is() )
             throw packages::NoEncryptionException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX ) ), uno::Reference< uno::XInterface >() );
 
-        return rZipPackage.getZipFile().getWrappedRawStream( aEntry, xEncryptionData, sMediaType, rZipPackage.GetSharedMutexRef() );
+        return rZipPackage.getZipFile().getWrappedRawStream( aEntry, GetEncryptionData(), sMediaType, rZipPackage.GetSharedMutexRef() );
     }
     else if ( GetOwnSeekStream().is() )
     {
@@ -516,13 +621,13 @@ Reference< io::XInputStream > SAL_CALL ZipPackageStream::getRawStream()
         else if ( m_nStreamMode == PACKAGE_STREAM_DATA && bToBeEncrypted )
             return TryToGetRawFromDataStream( sal_True );
     }
-    
+
     throw packages::NoEncryptionException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX ) ), uno::Reference< uno::XInterface >() );
 }
 
 
 //--------------------------------------------------------------------------
-void SAL_CALL ZipPackageStream::setDataStream( const Reference< io::XInputStream >& aStream )
+void SAL_CALL ZipPackageStream::setDataStream( const uno::Reference< io::XInputStream >& aStream )
         throw ( io::IOException,
                 RuntimeException )
 {
@@ -535,7 +640,7 @@ void SAL_CALL ZipPackageStream::setRawStream( const Reference< io::XInputStream
         throw ( packages::EncryptionNotAllowedException,
                 packages::NoRawFormatException,
                 io::IOException,
-                RuntimeException)
+                RuntimeException )
 {
     // wrap the stream in case it is not seekable
     Reference< io::XInputStream > xNewStream = ::comphelper::OSeekableInputWrapper::CheckSeekableCanWrap( aStream, m_xFactory );
@@ -555,7 +660,7 @@ void SAL_CALL ZipPackageStream::setRawStream( const Reference< io::XInputStream
 
     // the raw stream MUST have seekable access
     m_bHasSeekable = sal_True;
-    
+
     SetPackageMember ( sal_False );
     aEntry.nTime = -1;
     m_nStreamMode = PACKAGE_STREAM_RAW;
@@ -576,7 +681,7 @@ uno::Reference< io::XInputStream > SAL_CALL ZipPackageStream::getPlainRawStream(
 
     if (IsPackageMember())
     {
-        return rZipPackage.getZipFile().getRawData( aEntry, xEncryptionData, bIsEncrypted, rZipPackage.GetSharedMutexRef() );
+        return rZipPackage.getZipFile().getRawData( aEntry, GetEncryptionData(), bIsEncrypted, rZipPackage.GetSharedMutexRef() );
     }
     else if ( GetOwnSeekStream().is() )
     {
@@ -588,18 +693,18 @@ uno::Reference< io::XInputStream > SAL_CALL ZipPackageStream::getPlainRawStream(
         else if ( m_nStreamMode == PACKAGE_STREAM_DATA )
             return TryToGetRawFromDataStream( sal_False );
     }
-    
+
     return Reference< io::XInputStream >();
 }
 
 // XUnoTunnel
 
 //--------------------------------------------------------------------------
-sal_Int64 SAL_CALL ZipPackageStream::getSomething( const Sequence< sal_Int8 >& aIdentifier ) 
+sal_Int64 SAL_CALL ZipPackageStream::getSomething( const Sequence< sal_Int8 >& aIdentifier )
     throw(RuntimeException)
-{																
+{
     sal_Int64 nMe = 0;
-    if ( aIdentifier.getLength() == 16 && 
+    if ( aIdentifier.getLength() == 16 &&
          0 == rtl_compareMemory( static_getImplementationId().getConstArray(), aIdentifier.getConstArray(), 16 ) )
         nMe = reinterpret_cast < sal_Int64 > ( this );
     return nMe;
@@ -607,7 +712,7 @@ sal_Int64 SAL_CALL ZipPackageStream::getSomething( const Sequence< sal_Int8 >& a
 
 // XPropertySet
 //--------------------------------------------------------------------------
-void SAL_CALL ZipPackageStream::setPropertyValue( const OUString& aPropertyName, const Any& aValue ) 
+void SAL_CALL ZipPackageStream::setPropertyValue( const OUString& aPropertyName, const Any& aValue )
         throw(beans::UnknownPropertyException, beans::PropertyVetoException, IllegalArgumentException, WrappedTargetException, RuntimeException)
 {
     if (aPropertyName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("MediaType")))
@@ -654,8 +759,8 @@ void SAL_CALL ZipPackageStream::setPropertyValue( const OUString& aPropertyName,
                                                 2 );
 
             bToBeEncrypted = bEnc;
-            if ( bToBeEncrypted && xEncryptionData.isEmpty())
-                xEncryptionData = new EncryptionData;
+            if ( bToBeEncrypted && !m_xBaseEncryptionData.is())
+                m_xBaseEncryptionData = new BaseEncryptionData;
         }
         else
             throw IllegalArgumentException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX "Wrong type for Encrypted property!\n" ) ),
@@ -663,7 +768,7 @@ void SAL_CALL ZipPackageStream::setPropertyValue( const OUString& aPropertyName,
                                             2 );
 
     }
-    else if (aPropertyName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("EncryptionKey") ) )
+    else if (aPropertyName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM( ENCRYPTION_KEY_PROPERTY ) ) )
     {
         if ( rZipPackage.getFormat() != embed::StorageFormats::PACKAGE )
             throw beans::PropertyVetoException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX ) ), uno::Reference< uno::XInterface >() );
@@ -679,8 +784,8 @@ void SAL_CALL ZipPackageStream::setPropertyValue( const OUString& aPropertyName,
                 Sequence < sal_Int8 > aSequence ( nPathLength );
                 sal_Int8 *pArray = aSequence.getArray();
                 const sal_Unicode *pChar = sTempString.getStr();
-                for ( sal_Int16 i = 0; i < nPathLength; i++)
-                    pArray[i] = static_cast < const sal_Int8 > (pChar[i]);
+                for ( sal_Int16 i = 0; i < nPathLength; i++ )
+                    pArray[i] = static_cast < const sal_Int8 > ( pChar[i] );
                 aNewKey = aSequence;
             }
             else
@@ -691,22 +796,60 @@ void SAL_CALL ZipPackageStream::setPropertyValue( const OUString& aPropertyName,
 
         if ( aNewKey.getLength() )
         {
-            if ( xEncryptionData.isEmpty())
-                xEncryptionData = new EncryptionData;
+            if ( !m_xBaseEncryptionData.is() )
+                m_xBaseEncryptionData = new BaseEncryptionData;
 
-            xEncryptionData->aKey = aNewKey;
+            m_aEncryptionKey = aNewKey;
             // In case of new raw stream, the stream must not be encrypted on storing
             bHaveOwnKey = sal_True;
             if ( m_nStreamMode != PACKAGE_STREAM_RAW )
                 bToBeEncrypted = sal_True;
         }
         else
+        {
             bHaveOwnKey = sal_False;
+            m_aEncryptionKey.realloc( 0 );
     }
-    else if (aPropertyName.equalsAsciiL ( RTL_CONSTASCII_STRINGPARAM ( "Compressed" ) ) )
+
+        m_aStorageEncryptionKeys.realloc( 0 );
+    }
+    else if ( aPropertyName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( STORAGE_ENCRYPTION_KEYS_PROPERTY ) ) )
+    {
+        if ( rZipPackage.getFormat() != embed::StorageFormats::PACKAGE )
+            throw beans::PropertyVetoException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX ) ), uno::Reference< uno::XInterface >() );
+
+        uno::Sequence< beans::NamedValue > aKeys;
+        if ( !( aValue >>= aKeys ) )
+        {
+                throw IllegalArgumentException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX "Wrong type for StorageEncryptionKeys property!\n" ) ),
+                                                uno::Reference< XInterface >(),
+                                                2 );
+        }
+
+        if ( aKeys.getLength() )
+        {
+            if ( !m_xBaseEncryptionData.is() )
+                m_xBaseEncryptionData = new BaseEncryptionData;
+
+            m_aStorageEncryptionKeys = aKeys;
+
+            // In case of new raw stream, the stream must not be encrypted on storing
+            bHaveOwnKey = sal_True;
+            if ( m_nStreamMode != PACKAGE_STREAM_RAW )
+                bToBeEncrypted = sal_True;
+        }
+        else
+        {
+            bHaveOwnKey = sal_False;
+            m_aStorageEncryptionKeys.realloc( 0 );
+        }
+
+        m_aEncryptionKey.realloc( 0 );
+    }
+    else if ( aPropertyName.equalsAsciiL ( RTL_CONSTASCII_STRINGPARAM ( "Compressed" ) ) )
     {
         sal_Bool bCompr = sal_False;
-        
+
         if ( aValue >>= bCompr )
         {
             // In case of new raw stream, the stream must not be encrypted on storing
@@ -728,7 +871,7 @@ void SAL_CALL ZipPackageStream::setPropertyValue( const OUString& aPropertyName,
 }
 
 //--------------------------------------------------------------------------
-Any SAL_CALL ZipPackageStream::getPropertyValue( const OUString& PropertyName ) 
+Any SAL_CALL ZipPackageStream::getPropertyValue( const OUString& PropertyName )
         throw(beans::UnknownPropertyException, WrappedTargetException, RuntimeException)
 {
     Any aAny;
@@ -757,9 +900,14 @@ Any SAL_CALL ZipPackageStream::getPropertyValue( const OUString& PropertyName )
         aAny <<= bToBeCompressed;
         return aAny;
     }
-    else if (PropertyName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "EncryptionKey" ) ) )
+    else if (PropertyName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( ENCRYPTION_KEY_PROPERTY ) ) )
     {
-        aAny <<= xEncryptionData.isEmpty () ? Sequence < sal_Int8 > () : xEncryptionData->aKey;
+        aAny <<= m_aEncryptionKey;
+        return aAny;
+    }
+    else if ( PropertyName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( STORAGE_ENCRYPTION_KEYS_PROPERTY ) ) )
+    {
+        aAny <<= m_aStorageEncryptionKeys;
         return aAny;
     }
     else
@@ -768,7 +916,7 @@ Any SAL_CALL ZipPackageStream::getPropertyValue( const OUString& PropertyName )
 
 //--------------------------------------------------------------------------
 void ZipPackageStream::setSize (const sal_Int32 nNewSize)
-{ 
+{
     if (aEntry.nCompressedSize != nNewSize )
         aEntry.nMethod = DEFLATED;
     aEntry.nSize = nNewSize;
@@ -795,3 +943,4 @@ sal_Bool SAL_CALL ZipPackageStream::supportsService( OUString const & rServiceNa
     return rServiceName == getSupportedServiceNames()[0];
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
