@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -220,7 +221,7 @@ sal_Bool DocumentDigitalSignatures::ImplViewSignatures(
     sal_Bool bChanges = sal_False;
     DigitalSignaturesDialog aSignaturesDialog(
         NULL, mxCtx, eMode, bReadOnly, m_sODFVersion, m_bHasDocumentSignature);
-    bool bInit = aSignaturesDialog.Init( rtl::OUString() );
+    bool bInit = aSignaturesDialog.Init();
     DBG_ASSERT( bInit, "Error initializing security context!" );
     if ( bInit )
     {
@@ -230,7 +231,7 @@ sal_Bool DocumentDigitalSignatures::ImplViewSignatures(
         {
             if ( aSignaturesDialog.SignaturesChanged() )
             {
-                bChanges = TRUE;
+                bChanges = sal_True;
                 // If we have a storage and no stream, we are responsible for commit
                 if ( rxStorage.is() && !xSignStream.is() )
                 {
@@ -276,7 +277,7 @@ DocumentDigitalSignatures::ImplVerifySignatures(
 
     XMLSignatureHelper aSignatureHelper( mxCtx );
 
-    bool bInit = aSignatureHelper.Init( rtl::OUString() );
+    bool bInit = aSignatureHelper.Init();
 
     DBG_ASSERT( bInit, "Error initializing security context!" );
 
@@ -319,7 +320,7 @@ DocumentDigitalSignatures::ImplVerifySignatures(
             if (!rSigInfo.Signer.is())
                 rSigInfo.Signer = xSecEnv->getCertificate( rInfo.ouX509IssuerName, xSerialNumberAdapter->toSequence( rInfo.ouX509SerialNumber ) );
 
-            // --> PB 2004-12-14 #i38744# time support again
+            // Time support again (#i38744#)
             Date aDate( rInfo.stDateTime.Day, rInfo.stDateTime.Month, rInfo.stDateTime.Year );
             Time aTime( rInfo.stDateTime.Hours, rInfo.stDateTime.Minutes,
                         rInfo.stDateTime.Seconds, rInfo.stDateTime.HundredthSeconds );
@@ -339,7 +340,7 @@ DocumentDigitalSignatures::ImplVerifySignatures(
                     rSigInfo.CertificateStatus = xSecEnv->verifyCertificate(rSigInfo.Signer,
                         Sequence<Reference<css::security::XCertificate> >());
                 } catch (SecurityException& ) {
-                    OSL_ENSURE(0, "Verification of certificate failed");
+                    OSL_FAIL("Verification of certificate failed");
                     rSigInfo.CertificateStatus = css::security::CertificateValidity::INVALID;
                 }
             }
@@ -379,7 +380,7 @@ void DocumentDigitalSignatures::manageTrustedSources(  ) throw (RuntimeException
     Reference< dcss::xml::crypto::XSecurityEnvironment > xSecEnv;
 
     XMLSignatureHelper aSignatureHelper( mxCtx );
-    if ( aSignatureHelper.Init( rtl::OUString() ) )
+    if ( aSignatureHelper.Init() )
         xSecEnv = aSignatureHelper.GetSecurityEnvironment();
 
     MacroSecurity aDlg( NULL, mxCtx, xSecEnv );
@@ -391,13 +392,13 @@ void DocumentDigitalSignatures::showCertificate(
 {
     XMLSignatureHelper aSignatureHelper( mxCtx );
 
-    bool bInit = aSignatureHelper.Init( rtl::OUString() );
+    bool bInit = aSignatureHelper.Init();
 
     DBG_ASSERT( bInit, "Error initializing security context!" );
 
     if ( bInit )
     {
-        CertificateViewer aViewer( NULL, aSignatureHelper.GetSecurityEnvironment(), _Certificate, FALSE );
+        CertificateViewer aViewer( NULL, aSignatureHelper.GetSecurityEnvironment(), _Certificate, sal_False );
         aViewer.Execute();
     }
 
@@ -514,3 +515,4 @@ Reference< XInterface > DocumentDigitalSignatures_CreateInstance(
     return (cppu::OWeakObject*) new DocumentDigitalSignatures( rCtx );
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
